@@ -941,13 +941,13 @@ abstract class BaseRole extends Error {
 			foreach ($data as $sect => $refs) {
 				foreach ($refs as $refid => $value) {
 					$this->setSetting ($sect, $refid, $value) ;
-				}
-				if ($sect == 'scm') {
-					foreach ($this->getUsers() as $u) {
-						if (!$SYS->sysGroupCheckUser($refid,$u->getID())) {
-							$this->setError($SYS->getErrorMessage());
-							db_rollback();
-							return false;
+					if ($sect == 'scm') {
+						foreach ($this->getUsers() as $u) {
+							if (!$SYS->sysGroupCheckUser($refid,$u->getID())) {
+								$this->setError($SYS->getErrorMessage());
+								db_rollback();
+								return false;
+							}
 						}
 					}
 				}
@@ -1341,23 +1341,33 @@ abstract class RoleExplicit extends BaseRole implements PFO_RoleExplicit {
 		$already_there = array () ;
 		$res = db_query_params ('SELECT user_id FROM pfo_user_role WHERE user_id=ANY($1) AND role_id=$2',
 					array (db_int_array_to_any_clause($ids), $this->getID())) ;
+		if (!$res) {
+			return false;
+		}
 		while ($arr = db_fetch_array($res)) {
 			$already_there[] = $arr['user_id'] ;
 		}
 
 		foreach ($ids as $id) {
 			if (!in_array ($id, $already_there)) {
-			db_query_params ('INSERT INTO pfo_user_role (user_id, role_id) VALUES ($1, $2)',
-					 array ($id,
-						$this->getID())) ;
+				$res = db_query_params ('INSERT INTO pfo_user_role (user_id, role_id) VALUES ($1, $2)',
+							array ($id,
+							       $this->getID())) ;
+				if (!$res) {
+					return false;
+				}
 			}
 		}	
 
 		foreach ($this->getLinkedProjects() as $p) {
 			foreach ($ids as $uid) {
-				$SYS->sysGroupCheckUser($p->getID(),$uid) ;
+				if (!$SYS->sysGroupCheckUser($p->getID(),$uid)) {
+					return false;
+				}
 			}
 		}
+
+		return true;
 	}
 
 	public function addUser ($user) {
