@@ -818,10 +818,20 @@ function ShowResultSet($result,$title='',$linkify=false,$displayHeaders=true,$he
  *
  */
 function validate_email ($address) {
-	if ( preg_match( "/^[-!#$%&\'*+\\.\/0-9=?A-Z^_`a-z{|}~]+@[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.[-!#$%&\'*+\\.\/0-9=?A-Z^_`a-z{|}~]+$/", $address) ) {
-		return true;
-	} else {
-		return false;
+	if (version_compare(PHP_VERSION, '5.2.0', '>=')) {
+		if ( filter_var($address, FILTER_VALIDATE_EMAIL) ) {
+			return true;
+		}
+		else {
+			return false;
+		}
+	}
+	else {
+		if ( preg_match( "/^[-!#$%&\'*+\\.\/0-9=?A-Z^_`a-z{|}~]+@[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.[-!#$%&\'*+\\.\/0-9=?A-Z^_`a-z{|}~]+$/", $address) ) {
+			return true;
+		} else {
+			return false;
+		}
 	}
 }
 
