@@ -70,11 +70,9 @@ class ArtifactWorkflow extends Error {
 			
 			$res = db_query_params ('SELECT event_id 
 					FROM artifact_workflow_roles 
-					WHERE group_id=$1
-					AND event_id=$2
-					AND role_id=ANY($3)',
-						array ($this->ath->Group->getID(),
-						       $event_id,
+					WHERE event_id=$1
+					AND role_id=ANY($2)',
+						array ($event_id,
 						       db_int_array_to_any_clause($rids)));
 			return db_result($res, 0, 'event_id') ? true : false;
 		}
