@@ -1,8 +1,8 @@
-#! /usr/bin/php5
+#! /usr/bin/php
 <?php
 
 require_once (dirname(__FILE__)).'/../www/env.inc.php';
-require $gfwww.'include/squal_pre.php';
+require_once $gfcommon.'include/pre.php';
 
 db_begin();
 			      
