@@ -8,9 +8,9 @@
 # command line arguments.
 #
 # $HeadURL: http://svn.collab.net/repos/svn/branches/1.1.x/tools/hook-scripts/commit-email.pl.in $
-# $LastChangedDate: 2009-12-16 20:55:52 +0100 (mer. 16 déc. 2009) $
-# $LastChangedBy: aljeux $
-# $LastChangedRevision: 8533 $
+# $LastChangedDate$
+# $LastChangedBy$
+# $LastChangedRevision$
 #    
 # ====================================================================
 # Copyright (c) 2000-2004 CollabNet.  All rights reserved.
@@ -45,7 +45,7 @@ my ($sendmail, $smtp_server);
 # You should define exactly one of these two configuration variables,
 # leaving the other commented out, to select which method of sending
 # email should be used.
-$sendmail = "/usr/sbin/sendmail";
+$sendmail = $ENV{SENDMAIL} || "/usr/sbin/sendmail";
 #$smtp_server = "127.0.0.1";
 
 # Svnlook path.
