@@ -5,21 +5,20 @@
  * Copyright 2004 (c) GForge, LLC
  * http://gforge.org
  *
- * This file is part of GForge.
+ * This file is part of FusionForge. FusionForge is free software;
+ * you can redistribute it and/or modify it under the terms of the
+ * GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the Licence, or (at your option)
+ * any later version.
  *
- * GForge is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * GForge is distributed in the hope that it will be useful,
+ * FusionForge is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with GForge; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  US
+ * You should have received a copy of the GNU General Public License along
+ * with FusionForge; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 require_once $gfcommon.'include/Error.class.php';
@@ -301,9 +300,9 @@ $server->register(
 function &addDocument($session_ser,$group_id,$doc_group,$title,$description,$language_id, $base64_contents,$filename,$file_url) {
 	continue_session($session_ser);
 
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','addDocument','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','addDocument','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','addDocument',$g->getErrorMessage(),$g->getErrorMessage());
 	}
@@ -320,8 +319,7 @@ function &addDocument($session_ser,$group_id,$doc_group,$title,$description,$lan
 	}	
 
 	if ($base64_contents) {		
-		$bin_data = base64_decode($base64_contents);
-		$data = addslashes($bin_data);
+		$data = base64_decode($base64_contents);
 		$file_url='';
 		$uploaded_data_name=$filename;
 	} elseif ($file_url) { 
@@ -366,9 +364,9 @@ $server->register(
 function &updateDocument($session_ser,$group_id,$doc_group,$doc_id,$title,$description,$language_id, $base64_contents,$filename,$file_url,$state_id) {
 	continue_session($session_ser);
 			
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','updateDocument','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','updateDocument','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','updateDocument',$g->getErrorMessage(),$g->getErrorMessage());
 	}
@@ -408,8 +406,7 @@ function &updateDocument($session_ser,$group_id,$doc_group,$doc_id,$title,$descr
 
 	if((!$base64_contents) && (!$file_url)){	
 		if((!$base64_contents) && (!$d->isURL())){
-			$bin_data=$d->getFileData();
-			$data = addslashes($bin_data);
+			$data = $d->getFileData();
 			$uploaded_data_name=$d->getFileName();
 			$file_url='';
 		}else{
@@ -425,8 +422,7 @@ function &updateDocument($session_ser,$group_id,$doc_group,$doc_id,$title,$descr
 		$uploaded_data_name=$file_url;
 		$uploaded_data_type='URL';		
 	}elseif($base64_contents){
-		$bin_data = base64_decode($base64_contents);
-		$data = addslashes($bin_data);
+		$data = base64_decode($base64_contents);
 		$file_url='';
 		$uploaded_data_name=$filename;	
 	}		
@@ -464,9 +460,9 @@ $server->register(
 function &addDocumentGroup($session_ser,$group_id,$groupname,$parent_doc_group) {
 	continue_session($session_ser);
 
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','addDocumentGroup','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','addDocumentGroup','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','addDocumentGroup',$g->getErrorMessage(),$g->getErrorMessage());
 	}
@@ -507,9 +503,9 @@ $server->register(
 function &updateDocumentGroup($session_ser, $group_id, $doc_group, $new_groupname, $new_parent_doc_group) {
 	continue_session($session_ser);
 
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','updateDocumentGroup','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','updateDocumentGroup','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','updateDocumentGroup',$g->getErrorMessage(),$g->getErrorMessage());
 	}
@@ -550,9 +546,9 @@ $server->register(
 
 function &getDocuments($session_ser,$group_id,$doc_group_id) {
 	continue_session($session_ser);
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','getDocuments','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','getDocuments','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','getDocuments',$g->getErrorMessage(),$g->getErrorMessage());
 	}
@@ -619,9 +615,9 @@ $server->register(
 //
 function &getDocumentGroups($session_ser,$group_id) {
 	continue_session($session_ser);
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','getDocumentGroups','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','getDocumentGroups','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','getDocumentGroups',$g->getErrorMessage(),$g->getErrorMessage());
 	}
@@ -682,9 +678,9 @@ $server->register(
 //
 function &getDocumentGroup($session_ser,$group_id,$doc_group) {
 	continue_session($session_ser);
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','getDocumentGroup','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','getDocumentGroup','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','getDocumentGroup',$g->getErrorMessage(),$g->getErrorMessage());
 	}
@@ -728,9 +724,9 @@ $server->register(
 ///
 function &getDocumentFiles($session_ser,$group_id,$doc_id) {
 	continue_session($session_ser);
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','GetDocumentFiles','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','GetDocumentFiles','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','GetDocumentFiles',$g->getErrorMessage(),$g->getErrorMessage());
 	}
@@ -776,9 +772,9 @@ $server->register(
 function documentDelete($session_ser,$group_id,$doc_id) {
 	continue_session($session_ser);
 	
-	$g =& group_get_object($group_id);
+	$g = group_get_object($group_id);
 	if (!$g || !is_object($g)) {
-		return new soap_fault ('','documentDelete','Could Not Get Group','Could Not Get Group');
+		return new soap_fault ('','documentDelete','Could Not Get Project','Could Not Get Project');
 	} elseif ($g->isError()) {
 		return new soap_fault ('','documentDelete',$g->getErrorMessage(),$g->getErrorMessage());
 	}
